#!/bin/bash

. ./xivo-releases


for version in $versions; do
    dir_name="$release-$version"
    if [ ! -d data/$dir_name ]; then
        full_path="data/$dir_name/sources.list.d"
        sourceslist="$full_path/xivo-fai-skaro.list"
        mkdir -p $full_path
        echo "# XiVO Archive" > $sourceslist
        echo deb $mirror $repository-$version main non-free >> $sourceslist
        git add "data/$dir_name"
        echo "You have to commit your modification"
    fi
    control_file="debian/control"
    grep -Eo "Package: $dir_name" $control_file
    if [ $? -ne 0 ]; then
    cat <<- END >> $control_file

Package: $dir_name
Architecture: all
Provides:  xivo-fai, xivo-fai-skaro
Conflicts: xivo-fai, xivo-fai-skaro
Replaces:  xivo-fai, xivo-fai-skaro
Description: XIVO Skaro $version bootstrap
  Needed configuration to bootstrap a XIVO installation.
  .
  Homepage: http://www.xivo.fr/
END
    fi
done


function find_last_version() {
    IFS=$'\n'
    echo "${versions[*]}" | sort -nr | head -n1
}

function increment_version() {
    local changelog=$(head -1 debian/changelog)
    # look for a package version
    local existing_version
    if [[ "$changelog" =~ \((.*)\) ]] ; then
        existing_version=${BASH_REMATCH[1]}
    else
        echo "The first line of debian/changelog is '$changelog' and does not match \\(.*\\)" >&2
        return 1
    fi
    
    if [[ "$existing_version" =~ .*-(.*) ]] ; then
        new_version="-$(expr ${BASH_REMATCH[1]} + 1)"
    else
        echo "The first line of debian/changelog is '$changelog' and the package version $existing_version does not contain a debian version (i.e. something after a - as specified in man deb-version)" >&2
        return 3
    fi
    
    echo "1.0${new_version}"
    return 0
}

version=$(increment_version)
last_version=$(find_last_version)

dch -v $version --distribution squeeze-xivo-skaro-dev --force-distribution "add xivo $last_version"

dpkg-buildpackage -sa

dput squeeze ../xivo-fai_$version*.changes
dput squeeze-dev ../xivo-fai_$version*.changes
dput wheezy ../xivo-fai_$version*.changes

dh_clean

